# Insight

An **insight** is a presentation of \[some aggregate data within Launchable] that helps \[a persona] identify or fix \[a problem] that has an \[impact].

For example:

* The **test session duration graph** _(insight)_ helps a team lead _(persona)_ identify test session duration slowly creeping up _(problem)_ which signals increased developer cycle time _(impact of problem)_.
* The **test session frequency graph** helps a team lead identify that tests are being run less often which signals various negative health metrics (like increased cycle time, reduced quality, or fewer changes flowing through the pipeline).
* The **test session failure ratio graph** helps a team lead identify that tests are failing more often which could be a signal of release instability
* The **flaky test table** helps a developer identify which tests to fix first so they can reduce flakiness in their team’s test suite.

Stay tuned as we add more insights and insights pages!
